@@ -42,31 +42,37 @@ struct _Program {
 	 */
 	Toolkitgroup *kitg;
 
+	GtkActionGroup *action_group;
+	GtkUIManager *ui_manager;
 	GtkWidget *text;
-	GtkWidget *ctree;
-	GtkItemFactory *ifac;
+	gboolean dirty;		/* Has the text changed since we set it */
+	GtkWidget *tree;
+	GtkWidget *pane;
+	int pane_position;
+	guint refresh_timeout;	/* Timeout for UI refresh */
+	guint select_changed_sid;	
+	guint row_inserted_sid;	
+	guint row_deleted_sid;	
+
+	/* Track during drags.
+	 */
+	Toolkit *to_kit;
+	int to_pos;
+
+	/* Store for kit/tool view.
+	 */
+	GtkTreeStore *store;
 
 	/* Listen for all kit changes here.
 	 */
 	guint kitgroup_changed_sid;	
 	guint kitgroup_destroy_sid;		
 	
-	/* Track these during a tree update.
-	 */
-	GtkCTreeNode *sibling;	
-	GtkCTreeNode *parent;	
-
 	/* The current kit.
 	 */
 	Toolkit *kit;		
 	guint kit_destroy_sid;	
 
-	/* The symbol for the tool we are editing.
-	 */
-	Symbol *sym;	
-	gboolean dirty;		/* Has the text changed since we set it */
-	guint sym_changed_sid;	/* Listen for sym changes here */
-
 	/* The selected tool.
 	 */
 	Tool *tool;	
@@ -98,9 +104,6 @@ typedef struct _ProgramClass {
 	 */
 } ProgramClass;
 
-void program_freeze( void );
-void program_thaw( void );
-
 GtkType program_get_type( void );
 Program *program_new( Toolkitgroup *kitg );
 
