@@ -945,7 +945,12 @@ buf_appends( BufInfo *buf, const char *str )
 gboolean
 buf_appendc( BufInfo *buf, char ch )
 {
-	return( buf_appendns( buf, &ch, 1 ) );
+	char tiny[2];
+
+	tiny[0] = ch;
+	tiny[1] = '\0';
+
+	return( buf_appendns( buf, tiny, 1 ) );
 }
 
 /* Swap the rightmost occurence of old for new.
